@@ -30,3 +30,28 @@ get_glm_family <- function(fit) {
 
 # return names of objects passed as ellipses argument
 dot_names <- function(dots) unname(unlist(lapply(dots, as.character)))
+
+
+#' @importFrom tidyr nest
+#' @importFrom dplyr select_ filter
+#' @importFrom stats complete.cases
+get_grouped_data <- function(x) {
+  # nest data frame
+  grps <- tidyr::nest(x)
+
+  # remove NA category
+  cc <- grps %>%
+    dplyr::select_("-data") %>%
+    stats::complete.cases()
+  # select only complete cases
+  grps <- grps %>% dplyr::filter(cc)
+
+  # arrange data
+  if (length(attr(x, "vars", exact = T)) == 1)
+    reihe <- order(grps[[1]])
+  else
+    reihe <- order(grps[[1]], grps[[2]])
+  grps <- grps[reihe, ]
+
+  grps
+}
