@@ -1,28 +1,30 @@
-utils::globalVariables(c("strap", "models"))
+utils::globalVariables(c("strap", "models", "estimate"))
 
 #' @title Standard Error for variables or coefficients
 #' @name se
 #' @description Compute standard error for a variable, for all variables
 #'                of a data frame, for joint random and fixed effects
-#'                coefficients of mixed models, or for intraclass correlation
-#'                coefficients (ICC).
+#'                coefficients of (non-/linear) mixed models, the adjusted
+#'                standard errors for generalized linear (mixed) models, or
+#'                for intraclass correlation coefficients (ICC).
 #'
 #' @param x (Numeric) vector, a data frame, a \code{merMod}-object
-#'          as returned by the \code{\link[lme4]{lmer}}-method, an ICC object
-#'          (as obtained by the \code{\link{icc}}-function) or a list with
-#'          estimate and p-value. For the latter case, the list
-#'          must contain elements named \code{estimate} and \code{p.value}
-#'          (see 'Examples' and 'Details').
+#'          as returned by the functions from the \pkg{lme4}-package, a
+#'          \code{glm}-object, an ICC object (as obtained by the
+#'          \code{\link{icc}}-function) or a list with estimate and p-value.
+#'          For the latter case, the list must contain elements named
+#'          \code{estimate} and \code{p.value} (see 'Examples' and 'Details').
 #' @param nsim Numeric, the number of simulations for calculating the
 #'          standard error for intraclass correlation coefficients, as
 #'          obtained by the \code{\link{icc}}-function.
 #'
-#' @return The standard error of \code{x}, or for each variable
-#'           if \code{x} is a data frame, or for the coefficients
-#'           of a mixed model (see \code{\link[lme4]{coef.merMod}}).
+#' @return The standard error of \code{x}.
 #'
 #' @note Computation of standard errors for coefficients of mixed models
 #'         is based \href{http://stackoverflow.com/questions/26198958/extracting-coefficients-and-their-standard-error-from-lme}{on this code}.
+#'         \cr \cr
+#'         Standard errors for generalized linear (mixed) models are
+#'         approximations based on the delta method (Oehlert 1992).
 #'
 #' @details Unlike \code{\link[arm]{se.coef}}, which returns the standard error
 #'            for fixed and random effects separately, this function computes
@@ -30,6 +32,10 @@ utils::globalVariables(c("strap", "models"))
 #'            effects coefficients. Hence, \code{se()} returns the appropriate
 #'            standard errors for \code{\link[lme4]{coef.merMod}}.
 #'            \cr \cr
+#'            For generalized linear models or generalized linear mixed models,
+#'            approximated standard errors, using the delta method for transformed
+#'            regression parameters are returned (Oehlert 1992).
+#'            \cr \cr
 #'            The standard error for the \code{\link{icc}} is based on bootstrapping,
 #'            thus, the \code{nsim}-argument is required. See 'Examples'.
 #'            \cr \cr
@@ -38,17 +44,39 @@ utils::globalVariables(c("strap", "models"))
 #'            the z-score from the p-value (formula in short: \code{b / qnorm(p / 2)}).
 #'            See 'Examples'.
 #'
+#' @references Oehlert GW. 1992. A note on the delta method. American Statistician 46(1).
 #'
 #' @examples
+#' # compute standard error for vector
 #' se(rnorm(n = 100, mean = 3))
 #'
+#' # compute standard error for each variable in a data frame
 #' data(efc)
 #' se(efc[, 1:3])
 #'
+#' # compute standard error for merMod-coefficients
 #' library(lme4)
 #' fit <- lmer(Reaction ~ Days + (Days | Subject), sleepstudy)
 #' se(fit)
 #'
+#' # compute odds-ratio adjusted standard errors, based on delta method
+#' # with first-order Taylor approximation.
+#' data(efc)
+#' efc$services <- sjmisc::dicho(efc$tot_sc_e, dich.by = 0)
+#' fit <- glm(services ~ neg_c_7 + c161sex + e42dep,
+#'            data = efc, family = binomial(link = "logit"))
+#' se(fit)
+#'
+#' # compute odds-ratio adjusted standard errors for generalized
+#' # linear mixed model, also based on delta method
+#' library(lme4)
+#' library(sjmisc)
+#' # create binary response
+#' sleepstudy$Reaction.dicho <- dicho(sleepstudy$Reaction, dich.by = "median")
+#' fit <- glmer(Reaction.dicho ~ Days + (Days | Subject),
+#'              data = sleepstudy, family = binomial("logit"))
+#' se(fit)
+#'
 #' # compute standard error from regression coefficient and p-value
 #' se(list(estimate = .3, p.value = .002))
 #'
@@ -75,19 +103,40 @@ utils::globalVariables(c("strap", "models"))
 #' boot_p(dummy, icc)}
 #'
 #'
-#' @importFrom stats qnorm
+#' @importFrom stats qnorm vcov
+#' @importFrom broom tidy
+#' @importFrom dplyr mutate select_
 #' @export
 se <- function(x, nsim = 100) {
-  if (is_merMod(x)) {
-    # return standard error for mixed models
+  if (inherits(x, c("lmerMod", "nlmerMod", "merModLmerTest"))) {
+
+    # return standard error for (linear) mixed models
     return(std_merMod(x))
   } else if (inherits(x, "icc.lme4")) {
+
     # we have a ICC object, so do bootstrapping and compute SE for ICC
     return(std_e_icc(x, nsim))
+  } else if (inherits(x, c("glm", "glmerMod"))) {
+
+    # for glm, we want to exponentiate coefficients to get odds ratios, however
+    # 'exponentiate'-argument currently not works for lme4-tidiers
+    # so we need to do this manually for glmer's
+    tm <- broom::tidy(x, effects = "fixed")
+    tm$estimate <- exp(tm$estimate)
+    return(
+      tm %>%
+        # vcov for merMod returns a dpoMatrix-object, so we need
+        # to coerce to regular matrix here.
+        dplyr::mutate(or.se = sqrt(estimate ^ 2 * diag(as.matrix(stats::vcov(x))))) %>%
+        dplyr::select_("term", "estimate", "or.se") %>%
+        sjmisc::var_rename(or.se = "std.error")
+    )
   } else if (is.matrix(x) || is.data.frame(x)) {
+
     # init return variables
     stde <- c()
     stde_names <- c()
+
     # iterate all columns
     for (i in seq_len(ncol(x))) {
       # get and save standard error for each variable
@@ -96,14 +145,19 @@ se <- function(x, nsim = 100) {
       # save column name as variable name
       stde_names <- c(stde_names, colnames(x)[i])
     }
+
     # set names to return vector
     names(stde) <- stde_names
+
     # return results
     return(stde)
   } else if (is.list(x)) {
+
     # compute standard error from regression coefficient and p-value
     return(x$estimate / abs(stats::qnorm(x$p.value / 2)))
   } else {
+
+    # standard error for a variable
     return(std_e_helper(x))
   }
 }
